@@ -32,27 +32,19 @@ const retry = require('async-retry')
  *
  */
 const rp = opts => {
+  let url = opts.url
   if (opts.qs) {
-    // we turn the qs struct into a query string over the url
-    let first = true
-    for (let key in opts.qs) {
-      const str = `${encodeURIComponent(key)}=${encodeURIComponent(opts.qs[key])}`
-      if (first) {
-        opts.url += `?${str}`
-        first = false
-      } else {
-        opts.url += `&${str}`
-      }
-    }
+    url += '?' + Object.keys(opts.qs)
+      .map(key => `${encodeURIComponent(key)}=${encodeURIComponent(opts.qs[key])}`)
+      .join('&')
   }
-
   // it appears that certain call paths from our code do not set the
   // opts.json field to true; rp is apparently more resilient to
   // this situation than needle
   opts.json = true
 
   return needle(opts.method.toLowerCase(), // needle takes e.g. 'put' not 'PUT'
-    opts.url,
+    url,
     opts.body || opts.params,
     opts)
     .then(resp => {
